-- Convert old format databases into the MITAB2.6-capable format.

begin;

alter table mitab_interactions add column crogidA varchar;
alter table mitab_interactions add column crogidB varchar;
alter table mitab_interactions add column crigid varchar;

-- NOTE: From init_mitab.sql.

-- Genes related to interactors.
-- Only specific interactors in MITAB2.5 are supported here.

create table mitab_interactor_genes (
    "uid" varchar not null,           -- column 1 or 2 (MITAB2.5)
    entrezGene integer,               -- column 16 or 17 (MITAB2.5)
    primary key("uid", entrezGene)
);

-- Integer identifiers related to interactors.

create table mitab_interactor_rogs (
    "uid" varchar not null,           -- column 33 or 34 (specific)
    rog integer not null,             -- column 43 or 44 (specific)
    primary key("uid", rog)
);

create table mitab_canonical_interactor_rogs (
    "uid" varchar not null,           -- column 46 or 47 (canonical)
    rog integer not null,             -- column 49 or 50 (canonical)
    primary key("uid", rog)
);

-- Taxonomy identifiers (columns 10 and 11)
-- Only specific interactor taxonomy details are supported here.

create table mitab_interactor_taxonomy (
    "uid" varchar not null,           -- column 33 or 34
    taxid integer,                    -- column 10 or 11 (part, converted)
    primary key("uid", taxid)
);

insert into mitab_interactor_genes
    select uidA as uid, entrezGeneA
    from mitab_interactions
    where entrezGeneA is not null
    group by uidA, entrezGeneA
    union
    select uidB, entrezGeneB
    from mitab_interactions
    where entrezGeneB is not null
    group by uidB, entrezGeneB;

insert into mitab_interactor_rogs
    select uidA, rogA
    from mitab_interactions
    group by uidA, rogA
    union
    select uidB, rogB
    from mitab_interactions
    group by uidB, rogB;

insert into mitab_interactor_taxonomy
    select uidA, taxA
    from mitab_interactions
    where taxA is not null
    group by uidA, taxA
    union
    select uidB, taxB
    from mitab_interactions
    where taxB is not null
    group by uidB, taxB;

alter table mitab_interactions drop column entrezGeneA;
alter table mitab_interactions drop column entrezGeneB;
alter table mitab_interactions drop column rogA;
alter table mitab_interactions drop column rogB;
alter table mitab_interactions drop column taxA;
alter table mitab_interactions drop column taxB;

commit;
