begin;

-- Interactions.

create temporary table tmp_mitab_interactions (
    uidA varchar not null,            -- column 33 (specific)
    uidB varchar not null,            -- column 34 (specific)
    Atype varchar not null,           -- column 21
    Btype varchar not null,           -- column 22
    rigid varchar not null,           -- column 35 (specific)
    edgetype char(1) not null,        -- column 53
    numParticipants integer not null, -- column 54
    crogidA varchar,                  -- column 46 (canonical)
    crogidB varchar,                  -- column 47 (canonical)
    crigid varchar                    -- column 48 (canonical)
);

\copy tmp_mitab_interactions from '<directory>/mitab_interactions'

insert into mitab_interactions
    select distinct uidA, uidB, Atype, Btype, rigid, edgetype, numParticipants, crogidA, crogidB, crigid
    from tmp_mitab_interactions;

analyze mitab_interactions;

-- Genes related to interactors.

create temporary table tmp_mitab_interactor_genes (
    "uid" varchar not null,           -- column 1 or 2 (MITAB2.5)
    entrezGene integer                -- column 16 or 17 (MITAB2.5)
);

\copy tmp_mitab_interactor_genes from '<directory>/mitab_interactor_genes'

insert into mitab_interactor_genes
    select distinct "uid", entrezGene
    from tmp_mitab_interactor_genes;

analyze mitab_interactor_genes;

-- Integer identifiers related to interactors.

create temporary table tmp_mitab_interactor_rogs (
    "uid" varchar not null,           -- column 33 or 34 (specific)
    rog integer not null              -- column 43 or 44 (specific)
);

\copy tmp_mitab_interactor_rogs from '<directory>/mitab_interactor_rogs'

insert into mitab_interactor_rogs
    select distinct "uid", rog
    from tmp_mitab_interactor_rogs;

analyze mitab_interactor_rogs;

-- Integer identifiers related to canonical interactors.

create temporary table tmp_mitab_canonical_interactor_rogs (
    "uid" varchar not null,           -- column 46 or 47 (canonical)
    rog integer not null              -- column 49 or 50 (canonical)
);

\copy tmp_mitab_canonical_interactor_rogs from '<directory>/mitab_canonical_interactor_rogs'

insert into mitab_canonical_interactor_rogs
    select distinct "uid", rog
    from tmp_mitab_canonical_interactor_rogs;

analyze mitab_canonical_interactor_rogs;

-- Taxonomy identifiers.

create temporary table tmp_mitab_interactor_taxonomy (
    "uid" varchar not null,           -- column 33 or 34
    taxid integer                     -- column 10 or 11 (part, converted)
);

\copy tmp_mitab_interactor_taxonomy from '<directory>/mitab_interactor_taxonomy'

insert into mitab_interactor_taxonomy
    select distinct "uid", taxid
    from tmp_mitab_interactor_taxonomy;

analyze mitab_interactor_taxonomy;

-- Alternatives.

create temporary table tmp_mitab_alternatives (
    "uid" varchar not null,           -- column 33 or 34
    dbname varchar not null,          -- column 3 or 4 (part)
    alt varchar not null              -- column 3 or 4 (part)
);

\copy tmp_mitab_alternatives from '<directory>/mitab_alternatives'

insert into mitab_alternatives
    select distinct "uid", dbname, alt
    from tmp_mitab_alternatives;

analyze mitab_alternatives;

-- Aliases.

create temporary table tmp_mitab_aliases (
    "uid" varchar not null,           -- column 33 or 34
    dbname varchar not null,          -- column 5 or 6 (part)
    alias varchar not null            -- column 5 or 6 (part)
);

\copy tmp_mitab_aliases from '<directory>/mitab_aliases'

insert into mitab_aliases
    select distinct "uid", dbname, alias
    from tmp_mitab_aliases;

analyze mitab_aliases;

-- Method names.

create temporary table tmp_mitab_method_names (
    rigid varchar not null,           -- column 35
    code varchar not null,            -- column 7 (part)
    name varchar not null             -- column 7 (part)
);

\copy tmp_mitab_method_names from '<directory>/mitab_method_names'

insert into mitab_method_names
    select distinct rigid, code, name
    from tmp_mitab_method_names;

analyze mitab_method_names;

-- Authors.

create temporary table tmp_mitab_authors (
    rigid varchar not null,           -- column 35
    author varchar not null           -- column 8
);

\copy tmp_mitab_authors from '<directory>/mitab_authors'

insert into mitab_authors
    select distinct rigid, author
    from tmp_mitab_authors;

analyze mitab_authors;

-- PubMed references.

create temporary table tmp_mitab_pubmed (
    rigid varchar not null,           -- column 35
    pmid integer not null             -- column 9 (converted)
);

\copy tmp_mitab_pubmed from '<directory>/mitab_pubmed'

insert into mitab_pubmed
    select distinct rigid, pmid
    from tmp_mitab_pubmed;

analyze mitab_pubmed;

-- Interaction type names.

create temporary table tmp_mitab_interaction_type_names (
    rigid varchar not null,           -- column 35
    code varchar not null,            -- column 12 (part, only when available)
    name varchar not null             -- column 12 (part, only when available)
);

\copy tmp_mitab_interaction_type_names from '<directory>/mitab_interaction_type_names'

insert into mitab_interaction_type_names
    select distinct rigid, code, name
    from tmp_mitab_interaction_type_names;

analyze mitab_interaction_type_names;

-- Sources.

create temporary table tmp_mitab_sources (
    rigid varchar not null,           -- column 35
    sourcedb varchar not null,        -- column 13 (part, ophid is 'MI:0000')
    name varchar not null             -- column 13 (part)
);

\copy tmp_mitab_sources from '<directory>/mitab_sources'

insert into mitab_sources
    select distinct rigid, sourcedb, name
    from tmp_mitab_sources;

analyze mitab_sources;

-- Source interactions.

create temporary table tmp_mitab_interaction_identifiers (
    rigid varchar not null,           -- column 35
    dbname varchar not null,          -- column 14 (part)
    "uid" varchar not null            -- column 14 (part)
);

\copy tmp_mitab_interaction_identifiers from '<directory>/mitab_interaction_identifiers'

insert into mitab_interaction_identifiers
    select distinct rigid, dbname, "uid"
    from tmp_mitab_interaction_identifiers;

analyze mitab_interaction_identifiers;

-- Confidence scores.

create temporary table tmp_mitab_confidence (
    rigid varchar not null,           -- column 35
    "type" varchar not null,          -- column 15 (part)
    confidence integer not null       -- column 15 (part, converted)
);

\copy tmp_mitab_confidence from '<directory>/mitab_confidence'

insert into mitab_confidence
    select distinct rigid, "type", confidence
    from tmp_mitab_confidence;

analyze mitab_confidence;

commit;
